#[non_exhaustive]pub enum TurnEndReason {
Complete,
ToolsExecuted,
SteeringInterrupt,
Error,
Cancelled,
Aborted,
Transfer,
}Expand description
Why a turn ended.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Complete
Assistant completed without requesting tool calls.
ToolsExecuted
Tools were executed (loop continues).
SteeringInterrupt
Turn was interrupted by a steering message during tool execution.
Error
LLM returned an error stop reason.
Cancelled
External cancellation via CancellationToken.
Aborted
Stream was aborted mid-generation.
Transfer
Turn ended due to a transfer signal from a tool.