pub struct ComposedMessageProvider { /* private fields */ }Expand description
A MessageProvider that combines two providers, draining both on each poll.
Messages from the primary provider are returned first, followed by those from the secondary provider.
Implementations
Sourceimpl ComposedMessageProvider
impl ComposedMessageProvider
Sourcepub fn new(
primary: Arc<dyn MessageProvider>,
secondary: Arc<dyn MessageProvider>,
) -> Self
pub fn new( primary: Arc<dyn MessageProvider>, secondary: Arc<dyn MessageProvider>, ) -> Self
Create a composed provider from two providers.